# 2021-04-18 Authorizer

Initial version of the Authorizer contract, which powers Balancer governance.

This contract is expected to be eventually replaced by one with a) native support for timelocks and b) more granular roles, that is, being able to grant powers over a subset of related contracts. These development efforts are tracked [here](https://github.com/balancer-labs/balancer-v2-monorepo/milestone/4).

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet addresses](./output/arbitrum.json)
- [Optimism mainnet addresses](./output/optimism.json)
- [BSC mainnet addresses](./output/bsc.json)
- [Gnosis mainnet addresses](./output/gnosis.json)
- [Avalanche mainnet addresses](./output/avalanche.json)
- [Polygon zkeVM mainnet addresses](./output/zkevm.json)
- [Base mainnet addresses](./output/base.json)
- [Fantom mainnet addresses](./output/fantom.json)
- [Goerli testnet addresses](./output/goerli.json)
- [Sepolia testnet addresses](./output/sepolia.json)
- [`Authorizer` artifact](./artifact/Authorizer.json)
